
.. _series_as_features_ref:

Series-as-features tools
========================

The :mod:`aeon.series_as_features` module contains algorithms and composition tools that are shared by the classification and regression modules.

.. automodule:: aeon.series_as_features
    :no-members:
    :no-inherited-members:

Model selection
---------------

.. currentmodule:: aeon.series_as_features.model_selection

.. autosummary::
    :toctree: auto_generated/
    :template: class.rst

    PresplitFilesCV
    SingleSplit
